function [ lineHandles ] = draw_betti_curves_with_error_outline( bettis,...
    labels, confidence, ...
    lineColors, intervalColors, lineStyle, lineWidth,plotxMax, plotyMax)

% ----------------------------------------------------------------
% DRAW BETTI CURVES WITH ERROR
%
% From an array of multiple trials, draw mean betti curves
% and a specified confidence interval.
%
% INPUT:
%   bettis: A Ntrials x NFiltrations x maxDim matrix containing
%       the Betti curves to plot
%   labels: A NFiltrations x 1 vector with labels for the x-axis
%   confidence: percentile CI measure to shade
%   graphHandles: maxDim x 1 array of handles of axes into which to 
%       draw the graphs, one per dimension   
%   lineColors: maxDim x 3 array of RGB specifications for 
%       Betti curve colors 
%   intervalColors: maxDim x 3 array of RGB specifications for 
%       confidence interval colors
%   lineStyle: String specifyingline style in which to draw the 
%       curves, eg. '--'
%   lineWidth: Integer specification of line width for curves
%
% OUTPUT:
%   lineHandles: array of handles to the lines drawn for legend
%       purposes
% ----------------------------------------------------------------

maxDim = size(bettis, 3);
numFiltrations = size(bettis,2);

bettiCurves = squeeze(mean(bettis,1));
        
bettiCI = zeros(2, numFiltrations, maxDim);
for i=1:maxDim
    %bettiCI(1, :, i) = quantile(bettis(:,:,i), (1-confidence)/2);
    %bettiCI(2, :, i) = quantile(bettis(:,:,i), (1+confidence)/2);
    size(bettiCurves)
    size(bettis(:,:,i))
    size(std(bettis(:,:,i)))
    bettiCI(1,:,i) = bettiCurves(:,i)' + 2*std(bettis(:,:,i));
    bettiCI(2,:,i) = bettiCurves(:,i)' - 2*std(bettis(:,:,i))
end        

lineHandles = zeros(maxDim,1);
for i=1:maxDim
    subplot(3,1,i)
    %axes(graphHandles(i));
    hold on;    
    
    plot(labels,squeeze(bettiCI(1,:,i)),'Color',intervalColors(i,:))
    plot(labels,squeeze(bettiCI(2,:,i)),'Color',intervalColors(i,:))
    
    lineHandles(i)=plot(labels, bettiCurves(:,i), lineStyle, ...
        'Color', lineColors(i,:), 'LineWidth', lineWidth);
    hold off;
    axis([0 plotxMax 0 plotyMax])
end
    

end

